##
##  pecomato.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         pecomato
Summary:      Picture-Embedded Contents Manipulation Tool
URL:          http://www.mollux.org/projects/pecomato/
Vendor:       Tristan Chabredier
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Graphics
License:      GPL
Version:      0.0.15
Release:      20080101

#   list of sources
Source0:      http://www.mollux.org/projects/pecomato/download/sources/pecomato-%{version}.tar.bz2

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, make, gcc, python
PreReq:       OpenPKG, openpkg >= 20060823
AutoReq:      no
AutoReqProv:  no

%description
    PECoMaTo stands for Picture-Embedded Contents Manipulation Tool.

    It is basically designed to display any kind of information embedded
    in picture files, as well as checking, filtering, extracting, re-
    moving, adding and fixing such information. In other words, it's a
    metadata processor.

    It supports the following file formats: JPEG/JFIF, Adobe PSD and
    FFO, raw IPTC. And it knows about the following metadata formats:
    JFIF, IPTC, Exif, Adobe and Fotostation. More file and metadata
    formats might be supported later (TIFF, Adobe-specific metadata
    including XMP, etc.).

    One of its main goals is to check the validity of parsed metadata
    as well as optionally check the strict compliance to official
    standards. On another hand, it aims to provide ways of fixing broken
    or not compliant chunks as well as providing general basic functions
    to manipulate the metadata.

%track
    prog pecomato = {
        version   = %{version}
        url       = http://www.mollux.org/projects/pecomato/
        regex     = pecomato-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q

%build
    #   determine platform-specific Makefile
    makefile="Makefile.unix"
    case "%{l_platform -t}" in
        *-linux* ) makefile="Makefile.linux" ;;
    esac

    #   build pecomato
    %{l_make} %{l_mflags} -f $makefile clean all \
        CC="%{l_cc}" \
        PREFIX="%{l_prefix}"

    #   build manual page
    ( cd doc
      %{l_prefix}/bin/python ../devtools/txt2tags.py \
          --no-rc -t man -i manpage.t2t -o pecomato.1
    ) || exit $?

%install
    rm -rf $RPM_BUILD_ROOT

    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1

    #   install program and manual page
    %{l_shtool} install -c -s -m 755 \
        pecomato $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        doc/pecomato.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

